## Version v0.2.0 (2019/08/12)


### Pull Requests Merged

#### Bugs fixed

* [PR 36](https://github.com/pytroll/trollmoves/pull/36) - Prevent concurrent transfers when multiples sources are available
* [PR 35](https://github.com/pytroll/trollmoves/pull/35) - Fix move_it function to run with empty relative path
* [PR 31](https://github.com/pytroll/trollmoves/pull/31) - Bugfix: imports RawConfigParser rather than ConfigParser
* [PR 28](https://github.com/pytroll/trollmoves/pull/28) - Fix archive URI not being removed when unpacking
* [PR 27](https://github.com/pytroll/trollmoves/pull/27) - Fix error handling for client unpacking

#### Features added

* [PR 33](https://github.com/pytroll/trollmoves/pull/33) - Adding .stickler.yml configuration file
* [PR 32](https://github.com/pytroll/trollmoves/pull/32) - Add "nameservers" option to trollmoves client
* [PR 30](https://github.com/pytroll/trollmoves/pull/30) - Add config option for SSH key file
* [PR 20](https://github.com/pytroll/trollmoves/pull/20) - Restructure TrollMoves scripts

In this release 9 pull requests were closed.

## Version v0.1.3 (2019/04/10)

### Pull Requests Merged

#### Bugs fixed

* [PR 26](https://github.com/pytroll/trollmoves/pull/26) - Fix client untaring
* [PR 25](https://github.com/pytroll/trollmoves/pull/25) - Fix for new posttroll version, replacing context with get_context

In this release 2 pull requests were closed.

## Version v0.1.2 (2019/01/21)


### Pull Requests Merged

#### Bugs fixed

* [PR 23](https://github.com/pytroll/trollmoves/pull/23) - Fix the persistant ftp connection

#### Features added

* [PR 24](https://github.com/pytroll/trollmoves/pull/24) - Switch to versioneer
* [PR 22](https://github.com/pytroll/trollmoves/pull/22) - Remove Develop branch
* [PR 21](https://github.com/pytroll/trollmoves/pull/21) - Feature persistent connection
* [PR 17](https://github.com/pytroll/trollmoves/pull/17) - Feature posttroll serve
* [PR 16](https://github.com/pytroll/trollmoves/pull/16) - persistent ssh/scp connection
* [PR 15](https://github.com/pytroll/trollmoves/pull/15) - Make ftp connections persistent for 30 seconds
* [PR 14](https://github.com/pytroll/trollmoves/pull/14) - Feature client unpack
* [PR 13](https://github.com/pytroll/trollmoves/pull/13) - Improve error handling in SCPMover
* [PR 12](https://github.com/pytroll/trollmoves/pull/12) - Add support for Python 3
* [PR 11](https://github.com/pytroll/trollmoves/pull/11) - Added argument option disable-backlog
* [PR 8](https://github.com/pytroll/trollmoves/pull/8) - Introducing 'info' request

In this release 12 pull requests were closed.
